@@ -3,6 +3,9 @@ package App::livehttperf;
 BEGIN {
   $App::livehttperf::AUTHORITY = 'cpan:AJGB';
 }
+{
+  $App::livehttperf::VERSION = '0.02';
+}
 # ABSTRACT: Real life web performance testing tool
 
 use strict;
@@ -20,8 +23,6 @@ use Time::Elapsed qw( -compile elapsed );
 use List::Util qw( sum );
 use utf8;
 
-our $VERSION = '0.01';
-
 my @recs;
 my %stats;
 my @concurrency;
@@ -70,7 +71,7 @@ sub print_version {
     my $years = $year != 2012 ? "2012-$year" : '2012';
     binmode STDOUT, ":utf8";
     print <<EOV;
-livehttperf, version $VERSION  (perl $^V)
+livehttperf, version $App::livehttperf::VERSION  (perl $^V)
 
 This software is copyright (c) $years by Alex J. G. Burzyński <ajgb\@cpan.org>.
 
@@ -101,7 +102,7 @@ sub configure {
         'help' => sub { print_usage(); exit 0 },
     );
 
-    unless ( @ARGV || ! $rv ) {
+    unless ( @ARGV || $rv ) {
         print_usage();
         exit 1;
     }
@@ -162,7 +163,7 @@ sub configure {
         $xls->set_optimization();
         $xls->set_properties(
             title => 'Performance tests',
-            comments => "Generated by App::livehttperf/$VERSION",
+            comments => "Generated by App::livehttperf/$App::livehttperf::VERSION",
         );
         $bold = $xls->add_format();
         $bold->set_bold();
@@ -404,20 +405,21 @@ sub run_tests {
                     eval {
                         $res = $ua->request($req, $OPTS{verbosity} == 1 ? sub { print "." } : () )
                             or die "No response\n";
-
-                        LOG "[$tid.$no.$rec_no] RES:\n", $res->headers->as_string if DEBUG;
-                        LOG "[$tid.$no.$rec_no] RES:\n", $res->as_string if TRACE;
                     };
+                    my $err = $@;
                     push @{ $rec_stats_data{$rec_no} }, tv_interval( $rec_stats_start );
 
                     if ( $res ) {
+                        LOG "[$tid.$no.$rec_no] RES:\n", $res->headers->as_string if DEBUG;
+                        LOG "[$tid.$no.$rec_no] RES:\n", $res->as_string if TRACE;
+
                         my $res_headers = $res->headers;
                         $bytes_recv += $res_headers->header('Content-Length') ||
                             (length($res_headers->as_string) + length($res->content));
 
                         $res_statuses{int($res->code / 100) .'xx'}++;
                     }
-                    if ( $@ || ! response_matched($exp_res, $res) ) {
+                    if ( $err || ! response_matched($exp_res, $res) ) {
                         $failed_requests++;
                         $rec_errors{$rec_no}++;
                         if ( ERROR ) {
@@ -429,7 +431,7 @@ sub run_tests {
                             }
                         }
                         if ( TRACE ) {
-                            LOG "  Exception: $@" if $@;
+                            LOG "  Exception: $err" if $err;
                         }
                     } else {
                         $successful_requests++;
@@ -747,8 +749,10 @@ sub run {
 
 1;
 
-__END__
 
+
+
+__END__
 =pod
 
 =encoding utf-8
@@ -759,7 +763,7 @@ App::livehttperf - Real life web performance testing tool
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -767,7 +771,7 @@ version 0.01
 
 =head1 DESCRIPTION
 
-livehttperf is a web performance testing tool using recorded sessions from
+L<livehttperf> is a web performance testing tool using recorded sessions from
 L<LiveHTTP headers Firefox extension|http://livehttpheaders.mozdev.org/>.
 
 =head1 INSTALLATION
@@ -834,6 +838,8 @@ Use LibreOffice Calc to open saved result file (XLSX format).
 
 =over 4
 
+=item * L<livehttperf>
+
 =item * L<LiveHTTP headers Firefox extension|http://livehttpheaders.mozdev.org/>
 
 =item * L<Selenium IDE|http://seleniumhq.org/projects/ide/>
@@ -842,19 +848,7 @@ Use LibreOffice Calc to open saved result file (XLSX format).
 
 =back
 
-=head1 AUTHOR
-
-Alex J. G. Burzyński <ajgb@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Alex J. G. Burzyński <ajgb@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=for Pod::Coverage
-LOG
+=for Pod::Coverage LOG
 TRACE
 DEBUG
 INFO
@@ -873,6 +867,16 @@ save_results
 print_usage
 run
 
+=head1 AUTHOR
+
+Alex J. G. Burzyński <ajgb@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Alex J. G. Burzyński <ajgb@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-
